==> haskell-equivalence-0.3.4-17-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-equivalence.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: equivalence
version: 0.3.4
id: equivalence-0.3.4-7ULdc2PYU2qC9Kx6U0IEq2
key: equivalence-0.3.4-7ULdc2PYU2qC9Kx6U0IEq2
license: BSD-3-Clause
maintainer: paba@itu.dk
author: Patrick Bahr
stability: provisional
homepage: https://github.com/pa-ba/equivalence
synopsis: Maintaining an equivalence relation implemented as union-find using STT.
description:
    This is an implementation of Tarjan'\''s Union-Find algorithm (Robert
    E. Tarjan. "Efficiency of a Good But Not Linear Set Union
    Algorithm", JACM 22(2), 1975) in order to maintain an equivalence
    relation.
    This implementation is a port of the /union-find/ package using the
    ST monad transformer (instead of the IO monad).
category: Algorithms, Data
abi: 6dfa0ef7155e9a0b970c2c0f46d18e9e
exposed: True
exposed-modules:
    Data.Equivalence.Monad Data.Equivalence.STT
import-dirs: /usr/lib/ghc-8.6.5/site-local/equivalence-0.3.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/equivalence-0.3.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/equivalence-0.3.4
hs-libraries: HSequivalence-0.3.4-7ULdc2PYU2qC9Kx6U0IEq2
depends:
    STMonadTrans-0.4.4-DcWgHwC3dxa781E05oDqgk base-4.12.0.0
    containers-0.6.0.1 mtl-2.2.2 transformers-0.5.6.2
    transformers-compat-0.6.5-6PKzEe5EVLXd5Neg4mr6X
haddock-interfaces: /usr/share/doc/haskell-equivalence/html/equivalence.haddock
haddock-html: /usr/share/doc/haskell-equivalence/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-equivalence-0.3.4-18-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-equivalence.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: equivalence
version: 0.3.4
id: equivalence-0.3.4-JZF8l4fIhKYDZq7MEb55s6
key: equivalence-0.3.4-JZF8l4fIhKYDZq7MEb55s6
license: BSD-3-Clause
maintainer: paba@itu.dk
author: Patrick Bahr
stability: provisional
homepage: https://github.com/pa-ba/equivalence
synopsis: Maintaining an equivalence relation implemented as union-find using STT.
description:
    This is an implementation of Tarjan'\''s Union-Find algorithm (Robert
    E. Tarjan. "Efficiency of a Good But Not Linear Set Union
    Algorithm", JACM 22(2), 1975) in order to maintain an equivalence
    relation.
    This implementation is a port of the /union-find/ package using the
    ST monad transformer (instead of the IO monad).
category: Algorithms, Data
abi: 8d4155ecf303d4d6748b0b88c6a9f654
exposed: True
exposed-modules:
    Data.Equivalence.Monad Data.Equivalence.STT
import-dirs: /usr/lib/ghc-8.6.5/site-local/equivalence-0.3.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/equivalence-0.3.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/equivalence-0.3.4
hs-libraries: HSequivalence-0.3.4-JZF8l4fIhKYDZq7MEb55s6
depends:
    STMonadTrans-0.4.4-4a1MnFXjOE9659mRdznJrQ base-4.12.0.0
    containers-0.6.0.1 mtl-2.2.2 transformers-0.5.6.2
    transformers-compat-0.6.5-6PKzEe5EVLXd5Neg4mr6X
haddock-interfaces: /usr/share/doc/haskell-equivalence/html/equivalence.haddock
haddock-html: /usr/share/doc/haskell-equivalence/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
